##
## browser.py
## Login : <uli@pu.smp.net>
## Started on  Sun Jun 27 11:03:10 2010 Uli Fouquet
## $Id$
## 
## Copyright (C) 2010 Uli Fouquet
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for JAMB tables.
"""
import grok
from waeup.sirp.browser.pages import LoginPage
from waeup.sirp.applicants.interfaces import IApplicantPrincipal
from waeup.sirp.applicants import get_applicant_data
from waeup.sirp.interfaces import IWAeUPObject


class Login_PDE(LoginPage):
    grok.context(IWAeUPObject)
    grok.name('login_pde')

    title = 'PDE Login'
    pnav = 1

    def update(self):
        """Validate credentials and redirect or show error.

        The real validation is done by an pluggable authentication
        utility (PAU). Here we only check, whether correct credentials
        were entered by looking up the principal status of the
        request: If the user authenticated successfully, we get an
        applicant principal. Otherwise we get the unauthenticated
        principal.
        """
        formfields = ['form.ac_number', 'form.jamb_reg_no',
                      'form.ac_series', 'form.prefix',]

        self.reg_no = self.request.form.get('form.jamb_reg_no', '')
        self.ac_series = self.request.form.get('form.ac_series', '')
        self.ac_number = self.request.form.get('form.ac_number', '')

        for required_field in formfields:
            if required_field not in self.request.form.keys():
                return
        self.reg_no = self.request.form['form.jamb_reg_no']
        self.ac_series = self.request.form['form.ac_series']
        self.ac_number = self.request.form['form.ac_number']
        principal = self.request.principal
        if not IApplicantPrincipal.providedBy(principal):
            self.flash('You entered invalid credentials')
            return
        if hasattr(principal, 'reg_no'):
            if not principal.reg_no is None:
                
                site = grok.getSite()
                applications = site['applications']
                application = applications[principal.reg_no]
                self.redirect(self.url(application, '@@edit'))
        return

    def getCurrentSession(self):
        """Get the current session.

        XXX: This should be computed or retrieved from elsewhere.

        `session` here means an academic session, not a browser
        session.
        """
        return u'2010/2011'

    def getDeadline(self):
        """Get application submission deadline.

        XXX: This should be computed or retrieved from elsewhere.
        """
        return u"""Application submission deadline is at Midnight on Friday,
                   01. October 2010. No application will be treated
                   after the deadline."""

    def getApplicantData(self, reg_no, ac):
        """Validate credentials and return applicant data.

        Returns tuple ``(<APPLICANT_ENTRY>, <ACCESSCODE>) on
        successful validation and ``None`` else.

        We expect a JAMB registration number and an access code in
        format ``PUDE-XXX-XXXXXXXXXX``.

        See
        :func:`waeup.sirp.jambtables.util.get_applicant_data`
        for details.
        """
        return get_applicant_data(reg_no, ac)
